Crate runmat_core

Crate runmat_core 

Structs

ExecutionProfiling
ExecutionResult
ExecutionStats
ExecutionStreamEntry
FusionPlanDecision
FusionPlanEdge
FusionPlanNode
FusionPlanShader
FusionPlanSnapshot
InputRequest
MaterializedVariable
RunMatSession
Host-agnostic RunMat execution session (parser + interpreter + optional JIT).
StdinEvent
TelemetryFailureInfo
TelemetryPlatformInfo
TelemetryRunConfig
TelemetryRunFinish
TelemetryRunGuard
WorkspaceEntry
WorkspaceMaterializeOptions
WorkspacePreview
WorkspaceSliceOptions
WorkspaceSnapshot

Enums

CompatMode
ExecutionStreamKind
InputRequestKind
InputResponse
RunError
StdinEventKind
TelemetryHost
WorkspaceExportMode
WorkspaceMaterializeTarget
WorkspaceResidency

Traits

TelemetrySink
Host-provided transport for runtime telemetry events.

Functions

approximate_size_bytes
Rough estimate of the in-memory footprint for the provided value, in bytes.
execute_and_format
Execute MATLAB/Octave code and return the result as a formatted string
format_tokens
Tokenize the input string and return a space separated string of token names. This is kept for backward compatibility with existing tests.
matlab_class_name
MATLAB-style class name for a runtime value.
numeric_dtype_label
Returns a MATLAB dtype label for numeric values when available.
preview_numeric_values
Produce a numeric preview (up to limit elements) for scalars and dense arrays.
runtime_error_telemetry_failure_info
value_shape
Returns the MATLAB-style shape for the provided value when applicable.